import React, {useState, useEffect} from 'react';
import {ScrollView, ToastAndroid, Text} from 'react-native';
import useS3 from '../hooks/useS3';
import Bucket from '../components/Bucket';

const Buckets = () => {
	const s3 = useS3();
	const [buckets, setBuckets] = useState([]);
	const [loading, setLoading] = useState(true);

	useEffect(() => {
		if (s3 && !buckets.length) {
			s3.listBuckets({}, (err, data) => {
				if (err) {
					ToastAndroid.show('Failed to fetch buckets', ToastAndroid.SHORT);
					return;
				}

				setBuckets(data.Buckets);
				setLoading(false);
			});
		}
	}, [s3]);

	if (loading) {
		return <Text>Loading...</Text>;
	}

	return (
		<ScrollView>
			{buckets.map(bucket => (
				<Bucket key={bucket.Name} bucket={bucket} />
			))}
		</ScrollView>
	);
};

export default Buckets;
